@@ -1,12 +1,10 @@
 multi.snp.test <-
 function ( y , x , x.adj=NULL ,
-        type = c("gaussian", "binomial", "family","survival") ) {
+        type = c("gaussian", "binomial") ) {
 
      switch ( type,
            gaussian =  test <- "F" ,
-           binomial =  test <- "Chisq" ,
-           family   =  test <- "TDT"  ,
-           survival = { print("not ready!") ; stop("end") }  )
+           binomial =  test <- "Chisq"  )
 
    not.adjusted <- FALSE
    if ( all(is.null(x.adj)) ) { not.adjusted <- TRUE }
@@ -40,5 +38,4 @@ function ( y , x , x.adj=NULL ,
    return ( list ( fit.glm0=fit.glm0 , fit.glm1=fit.glm1 , aov.glm=aov.glm ,
      beta=coef(summary(fit.glm1)) )  )
      
-} # end of multi.snp.test
-
+}
